@@ -2,8 +2,9 @@ import logging
 from collections import OrderedDict
 
 import numpy as np
+
 from andes.core.model import Model, ModelData
-from andes.core.param import IdxParam, DataParam, NumParam
+from andes.core.param import DataParam, IdxParam, NumParam
 from andes.core.var import Algeb
 
 logger = logging.getLogger(__name__)
